==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineEvent.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.statemachine.Event;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEvent;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessage;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItem;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;


public interface StateMachineEvent extends IModelInstance<StateMachineEvent,Sql> {

    // attributes
    public void setSMevt_ID( UniqueId m_SMevt_ID ) throws XtumlException;
    public UniqueId getSMevt_ID() throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public UniqueId getSM_ID() throws XtumlException;
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public UniqueId getSMspd_IDdeprecated() throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public int getNumb() throws XtumlException;
    public void setMning( String m_Mning ) throws XtumlException;
    public String getMning() throws XtumlException;
    public void setIs_Lbl_U( int m_Is_Lbl_U ) throws XtumlException;
    public int getIs_Lbl_U() throws XtumlException;
    public String getUnq_Lbl() throws XtumlException;
    public void setUnq_Lbl( String m_Unq_Lbl ) throws XtumlException;
    public void setDrv_Lbl( String m_Drv_Lbl ) throws XtumlException;
    public String getDrv_Lbl() throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public String getDescrip() throws XtumlException;


    // operations


    // selections
    default public void addR1009_is_generated_by_EventMessage( EventMessage inst ) {}
    default public void removeR1009_is_generated_by_EventMessage( EventMessage inst ) {}
    public EventMessageSet R1009_is_generated_by_EventMessage() throws XtumlException;
    default public void addR2906_has_instances_PendingEvent( PendingEvent inst ) {}
    default public void removeR2906_has_instances_PendingEvent( PendingEvent inst ) {}
    public PendingEventSet R2906_has_instances_PendingEvent() throws XtumlException;
    default public void setR4759_is_basis_for_Event( Event inst ) {}
    public Event R4759_is_basis_for_Event() throws XtumlException;
    default public void setR502_SM_SM( SM_SM inst ) {}
    public SM_SM R502_SM_SM() throws XtumlException;
    default public void setR525_is_a_PolymorphicEvent( PolymorphicEvent inst ) {}
    public PolymorphicEvent R525_is_a_PolymorphicEvent() throws XtumlException;
    default public void setR525_is_a_SEMEvent( SEMEvent inst ) {}
    public SEMEvent R525_is_a_SEMEvent() throws XtumlException;
    default public void addR532_carries_StateMachineEventDataItem( StateMachineEventDataItem inst ) {}
    default public void removeR532_carries_StateMachineEventDataItem( StateMachineEventDataItem inst ) {}
    public StateMachineEventDataItemSet R532_carries_StateMachineEventDataItem() throws XtumlException;
    default public void addR706_CreateSMEventStatement( CreateSMEventStatement inst ) {}
    default public void removeR706_CreateSMEventStatement( CreateSMEventStatement inst ) {}
    public CreateSMEventStatementSet R706_CreateSMEventStatement() throws XtumlException;
    default public void addR707_GenerateSMEventStatement( GenerateSMEventStatement inst ) {}
    default public void removeR707_GenerateSMEventStatement( GenerateSMEventStatement inst ) {}
    public GenerateSMEventStatementSet R707_GenerateSMEventStatement() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineEvent.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.statemachine.Event;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEvent;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.message.EventMessage;
import io.ciera.tool.sql.ooaofooa.message.EventMessageSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SM;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItem;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;


public interface StateMachineEvent extends IModelInstance<StateMachineEvent,Sql> {

    // attributes
    public UniqueId getSMevt_ID() throws XtumlException;
    public void setSMevt_ID( UniqueId m_SMevt_ID ) throws XtumlException;
    public UniqueId getSM_ID() throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public UniqueId getSMspd_IDdeprecated() throws XtumlException;
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public int getNumb() throws XtumlException;
    public String getMning() throws XtumlException;
    public void setMning( String m_Mning ) throws XtumlException;
    public void setIs_Lbl_U( int m_Is_Lbl_U ) throws XtumlException;
    public int getIs_Lbl_U() throws XtumlException;
    public void setUnq_Lbl( String m_Unq_Lbl ) throws XtumlException;
    public String getUnq_Lbl() throws XtumlException;
    public void setDrv_Lbl( String m_Drv_Lbl ) throws XtumlException;
    public String getDrv_Lbl() throws XtumlException;
    public String getDescrip() throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;


    // operations


    // selections
    default public void addR1009_is_generated_by_EventMessage( EventMessage inst ) {}
    default public void removeR1009_is_generated_by_EventMessage( EventMessage inst ) {}
    public EventMessageSet R1009_is_generated_by_EventMessage() throws XtumlException;
    default public void addR2906_has_instances_PendingEvent( PendingEvent inst ) {}
    default public void removeR2906_has_instances_PendingEvent( PendingEvent inst ) {}
    public PendingEventSet R2906_has_instances_PendingEvent() throws XtumlException;
    default public void setR4759_Event( Event inst ) {}
    public Event R4759_Event() throws XtumlException;
    default public void setR502_SM_SM( SM_SM inst ) {}
    public SM_SM R502_SM_SM() throws XtumlException;
    default public void setR525_is_a_PolymorphicEvent( PolymorphicEvent inst ) {}
    public PolymorphicEvent R525_is_a_PolymorphicEvent() throws XtumlException;
    default public void setR525_is_a_SEMEvent( SEMEvent inst ) {}
    public SEMEvent R525_is_a_SEMEvent() throws XtumlException;
    default public void addR532_carries_StateMachineEventDataItem( StateMachineEventDataItem inst ) {}
    default public void removeR532_carries_StateMachineEventDataItem( StateMachineEventDataItem inst ) {}
    public StateMachineEventDataItemSet R532_carries_StateMachineEventDataItem() throws XtumlException;
    default public void addR706_CreateSMEventStatement( CreateSMEventStatement inst ) {}
    default public void removeR706_CreateSMEventStatement( CreateSMEventStatement inst ) {}
    public CreateSMEventStatementSet R706_CreateSMEventStatement() throws XtumlException;
    default public void addR707_GenerateSMEventStatement( GenerateSMEventStatement inst ) {}
    default public void removeR707_GenerateSMEventStatement( GenerateSMEventStatement inst ) {}
    public GenerateSMEventStatementSet R707_GenerateSMEventStatement() throws XtumlException;


}
